package com.company;

import ir.huri.jcal.JalaliCalendar;

import java.util.*;

/**
 * a class tha simulates a voting
 * stores voting question, choices, voters and all the votes that have been done
 */
public class Voting {
    private int type;
    private String question;
    private ArrayList<Person> voters;
    private HashMap<String, HashSet<Vote>> polls;

    /**
     * contructor for Voting class
     * @param type voters can choose one or more options(0 for one option and 1 for more than one)
     * @param question voting's question
     */
    public Voting(int type, String question){
        voters = new ArrayList<>();
        polls = new HashMap<>();
        this.type = type;
        this.question = question;
    }

    /**
     * adds a new choice to the current voting
     * @param newPoll the new choice we want to add
     */
    public void createPoll(String newPoll){
        polls.put(newPoll,new HashSet<Vote>());
    }

    /**
     * submits a vote on a choice that voter made
     * @param person the person that submitted the vote
     * @param answers a list ofchoices that have been submitted by voter
     */
    public void vote(Person person,ArrayList<String> answers) {
        for(Person guy : voters){
            if(guy.equals(person)){
                System.out.println("You have already voted");
                return;
            }
        }
        if (answers.size() > 1 && type == 0) {
            System.out.println("You can only submit one vote");
            return;
        }
        for (String answer : answers) {
            System.out.println("answer : "+answer);
            if (polls.get(answer) == null) {
                System.out.println("answer " + answer + " is not valid");
                return;
            }
            JalaliCalendar date = new JalaliCalendar(new GregorianCalendar());
            Vote temp = new Vote(person, date.toString());
            polls.get(answer).add(temp);
            voters.add(person);
            System.out.println("Vote submitted");
        }
    }


    public ArrayList<Person> getVoters() {
        return voters;
    }


    public HashMap<String, HashSet<Vote>> getPolls() {
        return polls;
    }

    /**
     * prints voting choices and number of votes on each choice
     */
    public void printResults(){
        System.out.println("Voting: " +question);
       polls.forEach((key,value) -> System.out.println("choice : " + key + " Number of votes : " + value.size()));
    }

    /**
     * prints all individual votes that have been submitted
     */
    public void printVotes(){
        polls.forEach((poll,votes) ->{
            for(Vote vote : votes){
                System.out.print(poll + " : ");
                vote.print();
            }
        });
    }


    public String getQuestion() {
        return question;
    }

    /**
     * prints all the choices for current poll
     */
    public void printPolls(){
        polls.forEach((poll,votes) -> System.out.println(poll));
    }



}
